Language class

A language spoken in a country.

Annotations
  • @freezed

Constructors

Language({required String code, required String name})
const
factory
Language.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

listFromMap(Map<String, dynamic>? map) List<Language>
Build a Language list from the v3.1 API map format {isoCode: name}.