TimeZone class

A UTC timezone offset, e.g. "+05:30", "-03:00", "00:00".

Annotations
  • @freezed

Constructors

TimeZone({required String offset})
const
factory
TimeZone.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String raw) TimeZone
Parse a raw timezone string (e.g. "UTC+05:30" → "+05:30", "UTC" → "+00:00").